@@ -459,9 +459,11 @@ bool gcpApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		}
 	}
 	if (file_type < 0 || (!bSave && (file_type > CHEMISTRY))) {
+		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, filename);
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-													_("Sorry, format not supported!"));
+													mess);
 		gtk_dialog_run (GTK_DIALOG (message));
+		g_free (mess);
 		gtk_widget_destroy (message);
 		return true;
 	}
@@ -560,7 +562,7 @@ void gcpApplication::SaveWithBabel (string const &filename, const gchar *mime_ty
 void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_type, gcpDocument* pDoc)
 {
 	char *old_num_locale;
-	bool bNew = (pDoc == NULL || (!pDoc->GetEmpty () && ! pDoc->GetDirty ())), local;
+	bool bNew = (pDoc == NULL || !pDoc->GetEmpty () || pDoc->GetDirty ()), local;
 	GnomeVFSFileInfo *info = NULL;
 	bool result = false, read_only = false;
 	try {
