@@ -31,6 +31,7 @@
 #include "theme.h"
 #include "view.h"
 #include "document.h"
+#include "Hposdlg.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-bpath.h"
@@ -45,7 +46,9 @@ using namespace gcu;
 #define ATOM_EPSILON 0.1
 
 gcpAtom::gcpAtom(): Atom(),
-	m_ShowSymbol (false)
+	DialogOwner (),
+	m_ShowSymbol (false),
+	m_HPosStyle (AUTO_HPOS)
 {
 	m_Valence = -1; //unspecified
 	m_nlp = 0;
@@ -86,7 +89,9 @@ gcpAtom::~gcpAtom()
 }
 
 gcpAtom::gcpAtom(int Z, double x, double y, double z): Atom(Z, x, y, z),
-	m_ShowSymbol (false)
+	DialogOwner (),
+	m_ShowSymbol (false),
+	m_HPosStyle (AUTO_HPOS)
 {
 	m_ChargeAuto = false;
 	m_HPos = GetBestSide();
@@ -106,7 +111,9 @@ gcpAtom::gcpAtom(int Z, double x, double y, double z): Atom(Z, x, y, z),
 }
 
 gcpAtom::gcpAtom(OBAtom* atom): Atom(),
-	m_ShowSymbol (false)
+	DialogOwner (),
+	m_ShowSymbol (false),
+	m_HPosStyle (AUTO_HPOS)
 {
 	m_x = atom->GetX();
 	m_y = - atom->GetY();
@@ -136,7 +143,7 @@ void gcpAtom::SetZ(int Z)
 	Atom::SetZ(Z);
 	m_Element = Element::GetElement (m_Z);
 	if ((m_Valence = m_Element->GetDefaultValence ()))
-		m_HPos = GetBestSide();
+		m_HPos = (m_HPosStyle == AUTO_HPOS)? GetBestSide(): m_HPosStyle;
 	else
 		m_nH = 0;
 	int max = m_Element->GetMaxValenceElectrons ();
@@ -251,7 +258,7 @@ void gcpAtom::Update ()
 				m_ChargeAuto = true;
 			}
 		}
-		m_HPos = GetBestSide();
+		m_HPos = (m_HPosStyle == AUTO_HPOS)? GetBestSide(): m_HPosStyle;
 	} else {
 		m_nH = 0;
 		if (m_ChargeAuto || !m_Charge) {
@@ -1526,6 +1533,10 @@ xmlNodePtr gcpAtom::Save (xmlDocPtr xml)
 	if (GetZ () == 6 && m_ShowSymbol) {
 		xmlNewProp (node, (xmlChar*) "show-symbol", (xmlChar*) "true");
 	}
+	if (m_HPosStyle != AUTO_HPOS) {
+		xmlNewProp (node, (xmlChar*) "H-position",
+					(xmlChar*) ((m_HPosStyle == LEFT_HPOS)? "left": "right"));
+	}
 	return node;
 }
 	
@@ -1599,6 +1610,16 @@ bool gcpAtom::Load (xmlNodePtr node)
 			m_ShowSymbol = true;
 		xmlFree (buf);
 	}
+	// Load H atoms position if any
+	buf = (char*) xmlGetProp (node, (xmlChar*) "H-position");
+	if (buf) {
+		if (!strcmp (buf, "left"))
+			m_HPosStyle = LEFT_HPOS;
+		else if (!strcmp (buf, "right"))
+			m_HPosStyle = RIGHT_HPOS;
+		xmlFree (buf);
+		Update ();
+	}
 	return true;
 }
 	
@@ -1693,21 +1714,45 @@ static void do_display_symbol (GtkToggleAction *action, gcpAtom* Atom)
 	Doc->GetView ()->Update (Atom);
 }
 
+static void do_choose_H_pos (gcpAtom* Atom)
+{
+	new gcpHPosDlg (static_cast<gcpDocument*> (Atom->GetDocument ()), Atom);
+}
+
 bool gcpAtom::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	bool result = false;
+	GtkActionGroup *group = NULL;
+	GtkAction *action;
 	if (GetZ () == 6 && GetBondsNumber() != 0) {
-		GtkActionGroup *group = gtk_action_group_new ("atom");
-		GtkAction *action;
+		group = gtk_action_group_new ("atom");
 		action = gtk_action_new ("Atom", _("Atom"),NULL, NULL);
 		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
 		action = GTK_ACTION (gtk_toggle_action_new ("show-symbol", _("Display symbol"),  _("Whether to display carbon atom symbol or not"), NULL));
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), m_ShowSymbol);
 		g_signal_connect (action, "toggled", G_CALLBACK (do_display_symbol), this);
 		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
 		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Atom'><menuitem action='show-symbol'/></menu></popup></ui>", -1, NULL);
-		gtk_ui_manager_insert_action_group (UIManager, group, 0);
 		result = true;
 	}
+	if (m_nH) {
+		if (!group) {
+			group = gtk_action_group_new ("atom");
+			action = gtk_action_new ("Atom", _("Atom"),NULL, NULL);
+			gtk_action_group_add_action (group, action);
+			g_object_unref (action);
+		}
+		action = GTK_ACTION (gtk_action_new ("H-position", _("Hydrogen atoms position"),  NULL, NULL));
+		g_signal_connect_swapped (action, "activate", G_CALLBACK (do_choose_H_pos), this);
+		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
+		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Atom'><menuitem action='H-position'/></menu></popup></ui>", -1, NULL);
+	}
+	if (group) {
+		gtk_ui_manager_insert_action_group (UIManager, group, 0);
+		g_object_unref (group);
+	}
 	return result | GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 }
