@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.h 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,8 +32,6 @@
 #include <libxml/tree.h>
 #include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print.h>
-#include <libbonobo.h>
-#include <libbonoboui.h>
 #include <gcu/document.h>
 #include <gcu/macros.h>
 #include "atom.h"
@@ -42,16 +40,6 @@
 #include "molecule.h"
 #include "operation.h"
 
-enum gcpFileTypes
-{
-	gcp_ft_Normal = 1,
-	gcp_ft_CML,
-	gcp_ft_SDF,
-	gcp_ft_PDB,
-	gcp_ft_ChemDraw,
-	gcp_ft_max
-};
-
 namespace OpenBabel
 {
 	class OBMol;
@@ -62,10 +50,10 @@ using namespace std;
 
 extern SignalId OnChangedSignal;
 extern SignalId OnDeleteSignal;
+extern SignalId OnThemeChangedSignal;
 
 class gcpView;
 class gcpApplication;
-class gcpDocPropDlg;
 class gcpWindow;
 class gcpTheme;
 
@@ -84,13 +72,13 @@ public:
 	bool ImportOB(OBMol& Mol);
 	void ExportOB();
 	void BuildAtomTable(map<string, unsigned>& AtomTable, Object* obj, unsigned& index);
-	void SetType(int Type) {m_FileType = Type; m_bWriteable = true;}
 	void Save();
 	virtual bool Load(xmlNodePtr);
 	const gchar* GetTitle();
 	void SetTitle(const gchar* title);
+	void SetLabel(const gchar* label);
 	const gchar* GetLabel();
-	void SetFileName (string const &, const gchar* ext);
+	void SetFileName (string const &, const gchar *mime_type);
 	const gchar* GetFileName() {return m_filename;}
 	void Print(GnomePrintContext *pc, gdouble width, gdouble height);
 	void AddObject(Object* pObject);
@@ -105,7 +93,6 @@ public:
 	void Remove(Object*);
 	void Remove(const char* Id);
 	void OnProperties();
-	void OnCloseProperties() {m_DocPropDlg = NULL;}
 	void OnUndo();
 	void OnRedo();
 	const GDate* GetCreationDate() {return &CreationDate;}
@@ -116,7 +103,6 @@ public:
 	void SetAuthor(const gchar* author);
 	void SetMail(const gchar* mail);
 	void SetComment(const gchar* comment);
-	void SetBonoboPersist(BonoboPersist* ps) {m_ps = ps;}
 	void FinishOperation();
 	void AbortOperation();
 	void PopOperation();
@@ -126,18 +112,19 @@ public:
 	gcpOperation* GetCurrentOperation () {return m_pCurOp;}
 	void AddData(xmlNodePtr node);
 	bool CanUndo() {return m_UndoList.size() > 0;}
-	void SetBonoboUI(BonoboUIComponent *uic) {m_pUic = uic;}
-	BonoboUIComponent * GetBonoboUI() {return m_pUic;}
 	void SetEditable(bool editable) {m_bWriteable = editable; m_bUndoRedo = true;}
 	bool GetEditable() {return m_bWriteable;}
 	gcpApplication* GetApplication() {return m_pApp;}
-	bool IsDirty () {return m_bDirty;}
 	void ExportImage (string const &filename, const char* type, int resolution = -1);
 	void SetReadOnly (bool ro);
 	bool GetReadOnly () {return m_bReadOnly;}
 	virtual double GetYAlign ();
 	gcpWindow *GetWindow () {return m_Window;}
 	void SetTheme (gcpTheme *theme);
+	bool OnSignal (SignalId Signal, Object *Child);
+	void SetDirty (bool isDirty = true);
+	void OnThemeNamesChanged ();
+	double GetMedianBondLength ();
 
 private:
 	void RemoveAtom(gcpAtom* pAtom);
@@ -152,15 +139,12 @@ private:
 	gchar *m_label;
 	gchar *m_comment, *m_author, *m_mail;
 	set<Object*>m_DirtyObjects;
-	BonoboPersist* m_ps;
-	bool m_bDirty, m_bIsLoading, m_bUndoRedo, m_bReadOnly;
-	int m_FileType;
+	bool m_bIsLoading, m_bUndoRedo, m_bReadOnly;
+	string m_FileType;
 	bool m_bWriteable;
-	gcpDocPropDlg* m_DocPropDlg;
 	GDate CreationDate, RevisionDate;
 	list<gcpOperation*> m_UndoList, m_RedoList;
 	gcpOperation* m_pCurOp;
-	BonoboUIComponent* m_pUic;
 	gcpApplication* m_pApp;
 	gcpWindow *m_Window;
 	unsigned long m_OpID; // last operation ID
