@@ -4,7 +4,7 @@
  * GChemPaint library
  * mesomery.cc 
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,21 +24,19 @@
 
 #include "gchempaint-config.h"
 #include "document.h"
+#include "theme.h"
 #include "widgetdata.h"
 #include "view.h"
-//#include "settings.h"
-//#include "libgcpcanvas/gcp-canvas-line.h"
-//#include "libgcpcanvas/gcp-canvas-group.h"
 #include "mesomery.h"
 #include "mesomery-arrow.h"
 #include "mesomer.h"
-#include <glib/gi18n.h>
-#include <math.h>
+#include <glib/gi18n-lib.h>
+#include <cmath>
 #include <set>
 
 gcpMesomery::gcpMesomery (): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId ((char*) "msy1");
 }
 
 gcpMesomery::~gcpMesomery ()
@@ -50,7 +48,7 @@ gcpMesomery::~gcpMesomery ()
 	gcpMesomeryArrow *arrow;
 	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
 	gcpOperation *pOp = pDoc->GetCurrentOperation ();
-	while (pObj = GetFirstChild (i)) {
+	while ((pObj = GetFirstChild (i))) {
 		if (pObj->GetType () == MesomeryArrowType) {
 			arrow = reinterpret_cast<gcpMesomeryArrow*> (pObj);
 			arrow->SetStartMesomer (NULL);
@@ -109,16 +107,6 @@ bool gcpMesomery::Load (xmlNodePtr node)
 	return true;
 }
 
-void gcpMesomery::Add (GtkWidget* w)
-{
-	map<string, Object*>::iterator i;
-	Object* p = GetFirstChild (i);
-	while (p) {
-		p->Add (w);
-		p = GetNextChild (i);
-	}
-}
-
 typedef struct
 {
 	double x, y;
@@ -128,7 +116,8 @@ typedef struct
 
 bool gcpMesomery::Build (list<Object*>& Children) throw (invalid_argument)
 {
-	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
+	gcpDocument *pDoc = dynamic_cast<gcpDocument *> (GetDocument ());
+	gcpTheme *pTheme = pDoc->GetTheme ();
 	gcpWidgetData  *pData= reinterpret_cast<gcpWidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
 	list<Object *>::iterator i, iend = Children.end ();
 	map<Object *, ObjectData> Objects;
@@ -141,7 +130,7 @@ bool gcpMesomery::Build (list<Object*>& Children) throw (invalid_argument)
 	for (i = Children.begin (); i != iend; i++) {
 		pData->GetObjectBounds (*i, &od.r);
 		od.x = (od.r.x0 + od.r.x1) / 2.;
-		od.y = (*i)->GetYAlign () * pData->ZoomFactor;
+		od.y = (*i)->GetYAlign () * pTheme->GetZoomFactor ();
 		switch ((*i)->GetType ()) {
 		case MoleculeType:
 			od.mes = new gcpMesomer (this, dynamic_cast<gcpMolecule *>(*i));
@@ -169,12 +158,12 @@ bool gcpMesomery::Build (list<Object*>& Children) throw (invalid_argument)
 		// x1, y1 will now be the coordinates of a normalized vector:
 		x1 -= x0;
 		y1 -= y0;
-		x0 *= pData->ZoomFactor;
-		y0 *= pData->ZoomFactor;
+		x0 *= pTheme->GetZoomFactor ();
+		y0 *= pTheme->GetZoomFactor ();
 		l = sqrt (x1 * x1 + y1 * y1);
 		x1 /= l;
 		y1 /= l;
-		l *= pData->ZoomFactor; // half length of the arrow on the screen
+		l *= pTheme->GetZoomFactor (); // half length of the arrow on the screen
 		// No molecule should be nearer than that
 		minright = minleft = DBL_MAX;
 		Left = Right = NULL;
@@ -501,9 +490,10 @@ static void ChainAdjust (MesomerData &md0, MesomerData &md1, double ratio, map<O
 
 void gcpMesomery::Align ()
 {
-	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
+	gcpDocument *pDoc = dynamic_cast <gcpDocument *> (GetDocument ());
 	gcpView *pView = pDoc->GetView ();
-	gcpWidgetData  *pData = reinterpret_cast<gcpWidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
+	gcpTheme *pTheme = pDoc->GetTheme ();
+	gcpWidgetData  *pData = reinterpret_cast <gcpWidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
 	/* Update the canvas if necessary */
 	GnomeCanvas* w = GNOME_CANVAS (((gcpDocument*) GetDocument ())->GetWidget ());
 	while (w->idle_id)
@@ -521,7 +511,7 @@ void gcpMesomery::Align ()
 		if (pObj->GetType () == MesomerType) {
 			pData->GetObjectBounds (pObj, &md.r);
 			md.x = (md.r.x0 + md.r.x1) / 2.;
-			md.y = pObj->GetYAlign () * pData->ZoomFactor;
+			md.y = pObj->GetYAlign () * pTheme->GetZoomFactor ();
 			md.chain = NULL;
 			md.m = dynamic_cast<gcpMesomer*> (pObj);
 			positions[pObj] = md;
@@ -556,7 +546,7 @@ void gcpMesomery::Align ()
 		// align the molecule
 		if ((*j).second->GetStartMesomer () != pStart)
 			(*j).second->Reverse ();
-		DoAlign ((*j).second, md0, md, pView->GetArrowPadding () * pData->ZoomFactor, pData->ZoomFactor);
+		DoAlign ((*j).second, md0, md, pTheme->GetArrowPadding (), pTheme->GetZoomFactor ());
 		positions[(*j).first] = md;
 	}
 	/* now add one mesomer to each growing chain and terminate chains when the end is
@@ -630,7 +620,7 @@ void gcpMesomery::Align ()
 				} else {
 					md.chain = md0.chain;
 					md.chain->mesomers.push_back ((*j).first);
-					DoAlign ((*j).second, md0, md, pView->GetArrowPadding () * pData->ZoomFactor, pData->ZoomFactor);
+					DoAlign ((*j).second, md0, md, pTheme->GetArrowPadding (), pTheme->GetZoomFactor ());
 					positions[(*j).first] = md;
 				}
 				break;
@@ -691,7 +681,7 @@ void gcpMesomery::Align ()
 					} else {
 						md.chain = md0.chain;
 						md.chain->mesomers.push_back ((*j).first);
-						DoAlign ((*j).second, md0, md, pView->GetArrowPadding () * pData->ZoomFactor, pData->ZoomFactor);
+						DoAlign ((*j).second, md0, md, pTheme->GetArrowPadding (), pTheme->GetZoomFactor ());
 						positions[(*j).first] = md;
 					}
 				}
@@ -708,14 +698,14 @@ void gcpMesomery::Align ()
 	// really move mesomers
 	map<Object*, MesomerData>::iterator p, pend= positions.end ();
 	for (p = positions.begin (); p != pend; p++)
-		(*p).first->Move ((*p).second.dx / pData->ZoomFactor, (*p).second.dy / pData->ZoomFactor);
+		(*p).first->Move ((*p).second.dx / pTheme->GetZoomFactor (), (*p).second.dy / pTheme->GetZoomFactor ());
 	gcpMesomeryArrow *arrow;
 	for (pObj = GetFirstChild (i); pObj; pObj = GetNextChild (i))
 		if (pObj->GetType () == MesomeryArrowType) {
 			arrow = static_cast<gcpMesomeryArrow*> (pObj);
 			md = positions[arrow->GetStartMesomer ()];
 			md0 = positions[arrow->GetEndMesomer ()];
-			AlignArrow (arrow, md, md0, pView->GetArrowPadding () * pData->ZoomFactor, pData->ZoomFactor);
+			AlignArrow (arrow, md, md0, pTheme->GetArrowPadding (), pTheme->GetZoomFactor ());
 		}
 	pView->Update (this);
 }
@@ -748,23 +738,25 @@ static void do_destroy_mesomery (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("mesomery");
 	GtkAction *action = gtk_action_new ("destroy-ms", _("Destroy the mesomery relationship"), NULL, NULL);
 	gtk_action_group_add_action (group, action);
+	g_object_unref (action);
 	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	g_object_unref (group);
 	char buf[] = "<ui><popup><menuitem action='destroy-ms'/></popup></ui>";
 	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy-ms");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_mesomery), this);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
 gcpMesomery::gcpMesomery (Object* parent, gcpMesomer *mesomer): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId ((char*) "msy1");
 	SetParent (parent);
 	AddChild (mesomer);
 	set<Object *> Objects;
@@ -781,9 +773,11 @@ double gcpMesomery::GetYAlign ()
 	Object *pObj;
 	pObj = GetFirstChild (i);
 	double y = DBL_MAX, new_y;
-	while (pObj)
+	while (pObj) {
 		if (pObj->GetType () == MesomerType)
 			if ((new_y = pObj->GetYAlign ()) < y)
-				y = new_y;			
+				y = new_y;
+		pObj = GetNextChild (i);
+	}
 	return y;
 }
