@@ -251,8 +251,13 @@ static bool on_delete_event (GtkWidget* widget, GdkEvent *event, gcpPrefsDlg* dl
 	return res;
 }
 
+static void on_default_theme_changed (GtkComboBox *box, gcpPrefsDlg* dlg)
+{
+	dlg->SetDefaultTheme (gtk_combo_box_get_active_text (box));
+}
+
 gcpPrefsDlg::gcpPrefsDlg (gcpApplication *pApp):
-	Dialog (pApp, DATADIR"/gchempaint/ui/preferences.glade", "preferences", pApp),
+	Dialog (pApp, GLADEDIR"/preferences.glade", "preferences", pApp),
 	Object (),
 	m_CurTheme (NULL),
 	m_Path (NULL)
@@ -289,12 +294,12 @@ gcpPrefsDlg::gcpPrefsDlg (gcpApplication *pApp):
 	m_FontSel = GCP_FONT_SEL (g_object_new (GCP_FONT_SEL_TYPE, NULL));
 	w = glade_xml_get_widget (xml, "atom-font-box");
 	gtk_box_pack_start_defaults (GTK_BOX (w), GTK_WIDGET (m_FontSel));
-	g_signal_connect (G_OBJECT (m_FontSel), "changed", G_CALLBACK (on_font_changed), this);
+	m_FontChanged = g_signal_connect (G_OBJECT (m_FontSel), "changed", G_CALLBACK (on_font_changed), this);
 	// add text font selector
 	m_TextFontSel = GCP_FONT_SEL (g_object_new (GCP_FONT_SEL_TYPE, NULL));
 	w = glade_xml_get_widget (xml, "text-box");
 	gtk_box_pack_start_defaults (GTK_BOX (w), GTK_WIDGET (m_TextFontSel));
-	g_signal_connect (G_OBJECT (m_TextFontSel), "changed", G_CALLBACK (on_text_font_changed), this);
+	m_TextFontChanged = g_signal_connect (G_OBJECT (m_TextFontSel), "changed", G_CALLBACK (on_text_font_changed), this);
 	// arrow spin buttons
 	m_ArrowLengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "arrow-length-btn"));
 	g_signal_connect (G_OBJECT (m_ArrowLengthBtn), "value-changed", G_CALLBACK (on_arrow_length_changed), this);
@@ -343,9 +348,18 @@ gcpPrefsDlg::gcpPrefsDlg (gcpApplication *pApp):
 	string default_name = pApp->GetActiveDocument ()->GetTheme ()->GetName ();
 	if (default_name == "Default")
 			default_name = _("Default");
-	gcpTheme *theme;
+	gcpTheme *theme, *default_theme = ThemeManager.GetDefaultTheme ();
+	m_DefaultThemeBox = GTK_COMBO_BOX (gtk_combo_box_new_text ());
+	gtk_table_attach (GTK_TABLE (glade_xml_get_widget (xml, "table1")), GTK_WIDGET (m_DefaultThemeBox), 1, 3, 2, 3,
+													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+													   (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+	int n = 0;
 	for (i = theme_names.begin (); i != iend; i++) {
 		theme = ThemeManager.GetTheme (*i);
+		gtk_combo_box_append_text (m_DefaultThemeBox, (*i).c_str ());
+		if (theme == default_theme)
+			gtk_combo_box_set_active (m_DefaultThemeBox, n);
+		n++;
 		if (theme)
 			theme->AddClient (this);
 		gtk_tree_store_append (themes, &iter, NULL);
@@ -383,6 +397,7 @@ gcpPrefsDlg::gcpPrefsDlg (gcpApplication *pApp):
 				  0, _("Text"),
 				  -1);
 	}
+	g_signal_connect (m_DefaultThemeBox,"changed", G_CALLBACK (on_default_theme_changed), this);
 	m_Path = gtk_tree_model_get_path (GTK_TREE_MODEL (themes), &selected);
 	gtk_tree_selection_set_mode (m_ThemesSelection, GTK_SELECTION_BROWSE);
 	g_signal_connect (m_ThemesSelection, "changed", G_CALLBACK (on_select_theme), this);
@@ -474,7 +489,10 @@ void gcpPrefsDlg::OnSelectTheme (GtkTreeSelection *selection)
 	char *name;
 	char *page;
 	GtkTreeModel *model;
-	gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gtk_notebook_set_current_page (m_Book, 0);
+		return;
+	}
 	if (m_Path)
 		gtk_tree_path_free (m_Path);
 	m_Path = gtk_tree_model_get_path (GTK_TREE_MODEL (themes), &iter);
@@ -520,6 +538,7 @@ void gcpPrefsDlg::OnSelectTheme (GtkTreeSelection *selection)
 	gtk_widget_set_sensitive (GTK_WIDGET (m_HashWidthBtn), rw);
 	gtk_spin_button_set_value (m_HashDistBtn, m_CurTheme->m_HashDist);
 	gtk_widget_set_sensitive (GTK_WIDGET (m_HashDistBtn), rw);
+	g_signal_handler_block (G_OBJECT (m_TextFontSel), m_TextFontChanged);
 	g_object_set (G_OBJECT (m_TextFontSel),
 					"family", m_CurTheme->m_TextFontFamily,
 					"style", m_CurTheme->m_TextFontStyle,
@@ -528,7 +547,9 @@ void gcpPrefsDlg::OnSelectTheme (GtkTreeSelection *selection)
 					"stretch", m_CurTheme->m_TextFontStretch,
 					"size", m_CurTheme->m_TextFontSize,
 					NULL);
+	g_signal_handler_unblock (G_OBJECT (m_TextFontSel), m_TextFontChanged);
 	gtk_widget_set_sensitive (GTK_WIDGET (m_TextFontSel), rw);
+	g_signal_handler_block (G_OBJECT (m_FontSel), m_FontChanged);
 	g_object_set (G_OBJECT (m_FontSel),
 					"family", m_CurTheme->m_FontFamily,
 					"style", m_CurTheme->m_FontStyle,
@@ -537,6 +558,7 @@ void gcpPrefsDlg::OnSelectTheme (GtkTreeSelection *selection)
 					"stretch", m_CurTheme->m_FontStretch,
 					"size", m_CurTheme->m_FontSize,
 					NULL);
+	g_signal_handler_unblock (G_OBJECT (m_FontSel), m_FontChanged);
 	gtk_widget_set_sensitive (GTK_WIDGET (m_FontSel), rw);
 	gtk_spin_button_set_value (m_ArrowLengthBtn, m_CurTheme->m_ArrowLength);
 	gtk_widget_set_sensitive (GTK_WIDGET (m_ArrowLengthBtn), rw);
@@ -1442,3 +1464,16 @@ bool gcpPrefsDlg::CheckError ()
 {
 	return (!*gtk_entry_get_text (m_NameEntry));
 }
+
+void gcpPrefsDlg::SetDefaultTheme (char const *name)
+{
+	ThemeManager.SetDefaultTheme (name);
+	GConfClient *conf_client = gconf_client_get_default ();
+	GError *error = NULL;
+	gconf_client_set_string (conf_client, ROOTDIR"default-theme", name, &error);
+	if (error) {
+		g_message("GConf failed: %s", error->message);
+		g_error_free (error);
+	}
+	g_object_unref (conf_client);
+}
