@@ -87,13 +87,13 @@ gcpTheme::gcpTheme (char const *name)
 	m_ObjectPadding = DefaultObjectPadding;
 	m_SignPadding = DefaultSignPadding;
 	m_ChargeSignSize = DefaultChargeSignSize;
-	m_FontFamily = strdup (DefaultFontFamily);
+	m_FontFamily = strdup ((DefaultFontFamily)? DefaultFontFamily: "Bitstream Vera Sans");
 	m_FontStyle = DefaultFontStyle;
 	m_FontWeight = DefaultFontWeight;
 	m_FontVariant = DefaultFontVariant;
 	m_FontStretch = DefaultFontStretch;
 	m_FontSize = DefaultFontSize;
-	m_TextFontFamily = strdup (DefaultTextFontFamily);
+	m_TextFontFamily = strdup ((DefaultTextFontFamily)? DefaultTextFontFamily: "Bitstream Vera Serif");
 	m_TextFontStyle = DefaultTextFontStyle;
 	m_TextFontWeight = DefaultTextFontWeight;
 	m_TextFontVariant = DefaultTextFontVariant;
@@ -197,7 +197,7 @@ gcpThemeManager::gcpThemeManager ()
 	GCU_GCONF_GET (ROOTDIR"hash-width", float, DefaultHashWidth, 1.0)
 	GCU_GCONF_GET (ROOTDIR"hash-dist", float, DefaultHashDist, 2.0)
 	GCU_GCONF_GET (ROOTDIR"stereo-width", float, DefaultStereoBondWidth, 5.0)
-	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"scale", float, DefaultZoomFactor, 0.25, inv)
+	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"scale", float, DefaultZoomFactor, 4.0, inv)
 	GCU_GCONF_GET (ROOTDIR"padding", float, DefaultPadding, 2.0)
 	GCU_GCONF_GET (ROOTDIR"arrow-padding", float, DefaultArrowPadding, 16.0)
 	GCU_GCONF_GET (ROOTDIR"stoichiometry-padding", float, DefaultStoichiometryPadding, 1.)
@@ -218,8 +218,8 @@ gcpThemeManager::gcpThemeManager ()
 	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"text-font-size", float, DefaultTextFontSize, 12., set_fontsize)
 	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchempaint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
 	// Build default theme from settings
-	m_Themes["Default"] = m_Themes[_("Default")] = new gcpTheme ("Default");
-	m_Names.push_front (_("Default"));
+	m_Themes["GChemPaint"] = new gcpTheme ("GChemPaint");
+	m_Names.push_front ("GChemPaint");
 	// load global themes
 	string path = DATADIR;
 	path += "/gchempaint/themes";
@@ -230,6 +230,12 @@ gcpThemeManager::gcpThemeManager ()
 		path = szhome;
 	path += "/.gchempaint/themes";
 	ParseDir (path, LOCAL_THEME_TYPE);
+	gchar *default_theme  =NULL;
+	GCU_GCONF_GET_STRING (ROOTDIR"default-theme", default_theme, "GChemPaint");
+	m_DefaultTheme = m_Themes[default_theme];
+	g_free (default_theme);
+	if (!m_DefaultTheme)
+		m_DefaultTheme = m_Themes["GChemPaint"];
 }
 
 gcpThemeManager::~gcpThemeManager ()
@@ -279,11 +285,15 @@ gcpThemeManager::~gcpThemeManager ()
 
 gcpTheme *gcpThemeManager::GetTheme (char const *name)
 {
+	if (!strcmp (_(name), _("Default")))
+		return m_DefaultTheme;
 	return m_Themes[name];
 }
 
 gcpTheme *gcpThemeManager::GetTheme (string &name)
 {
+	if (name == "Default" || name == _("Default") )
+		return m_DefaultTheme;
 	return m_Themes[name.c_str ()];
 }
 
@@ -298,7 +308,7 @@ void gcpThemeManager::OnConfigChanged (GConfClient *client, guint cnxn_id, GConf
 		return;	// we might want an error message?
 	if (cnxn_id != m_NotificationId)
 		return;	// we might want an error message?
-	gcpTheme *Theme = m_Themes["Default"];
+	gcpTheme *Theme = m_Themes["GChemPaint"];
 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"bond-length")) {
 		DefaultBondLength = gconf_value_get_float (gconf_entry_get_value (entry));
 		Theme->m_BondLength = DefaultBondLength;
@@ -405,6 +415,11 @@ void gcpThemeManager::OnConfigChanged (GConfClient *client, guint cnxn_id, GConf
 	} else if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"text-font-size"))  {
 		DefaultTextFontSize = set_fontsize (gconf_value_get_float (gconf_entry_get_value (entry)));
 		Theme->m_TextFontSize = DefaultTextFontSize;
+	} else if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"default-theme"))  {
+		char const *name = gconf_value_get_string (gconf_entry_get_value (entry));
+		gcpTheme *pTheme = m_Themes[name];
+		if (pTheme)
+			m_DefaultTheme = pTheme;
 	}
 }
 
@@ -472,6 +487,8 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 	if (dir) {
 		path += "/";
 		while ((name = g_dir_read_name (dir))) {
+			if (name[strlen (name) - 1] == '~')
+				continue; // don't read backups
 			filename = path + name;
 			doc = xmlParseFile (filename.c_str ());
 			node = doc->children;
@@ -489,6 +506,8 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 					if (theme->m_ThemeType == DEFAULT_THEME_TYPE || theme->m_ThemeType == GLOBAL_THEME_TYPE)
 						name = _(name);
 					if (m_Themes.find (name) != m_Themes.end ()) {
+						delete theme;
+						continue;
 					}
 					theme->m_ThemeType = type;
 					m_Themes[name] = theme;
@@ -504,6 +523,8 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 void gcpThemeManager::AddFileTheme (gcpTheme *theme, char const *label)
 {
 	string name = theme->GetName ().c_str ();
+	if (name == "Default")
+		name = "GChemPaint";
 	if (m_Themes.find (name) != m_Themes.end ()) {
 		name = string (label) + ":" + name;
 	}
@@ -533,6 +554,14 @@ void gcpThemeManager::ChangeThemeName (gcpTheme *theme, char const *name)
 	m_Names.push_back (name);
 }
 
+void gcpThemeManager::SetDefaultTheme (char const *name)
+{
+	gcpTheme *pTheme = m_Themes[name];
+	if (pTheme) {
+		m_DefaultTheme = pTheme;
+	}
+}
+
 bool gcpTheme::Save (xmlDocPtr xml)
 {
 	xmlNodePtr node = xmlNewDocNode (xml, NULL, (xmlChar*) "theme", NULL);
