@@ -810,9 +810,10 @@ bool gcpView::OnKeyPress(GtkWidget* w, GdkEventKey* event)
 				break;
 			}
 			if (Z) {
-				gcpTools *tools = static_cast<gcpTools*> (pApp->GetDialog ("tools"));
-				tools->SetElement (Z);
-				if (atom && atom->GetZ () != Z && Element::GetElement (Z)->GetMaxBonds () >= min_bonds) {
+				if (!atom) {
+					gcpTools *tools = static_cast<gcpTools*> (pApp->GetDialog ("tools"));
+					tools->SetElement (Z);
+				} else if (atom->GetZ () != Z && Element::GetElement (Z)->GetMaxBonds () >= min_bonds) {
 					Object *group = atom->GetGroup ();
 					gcpOperation *op = m_pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
 					op->AddObject (group);
